PERL

#
# SMxGauss, version 3.3, January 2006
#

#
# Most of the program is organized in subroutines located in
# SMxLib
#
require "LIB/heading.lib";
require "LIB/initialize.lib";
require "LIB/molecspec.lib";
require "LIB/procbasis.lib";
require "LIB/procinput.lib";
require "LIB/prockeyword.lib";
require "LIB/proclogic.lib";
require "LIB/procopt.lib";
require "LIB/procoverride.lib";
require "LIB/procscf.lib";
require "LIB/procsmx.lib";
require "LIB/procsolvent.lib";
require "LIB/prtext.lib";
require "LIB/suminp.lib";
require "LIB/punch.lib";
require "LIB/procoutput.lib";
require "LIB/output.lib";
require "LIB/mode.lib";
require "LIB/mkhndplus.lib";
require "LIB/prochndplus.lib";
require "LIB/mkgauss.lib";
require "LIB/procgauss.lib";
require "LIB/io.lib";
#
# Available keywords: Note that Keep is undocumented.  It can be used
# to save temporary files
#
@keywords = ("SCF","OPT","FREQ","Solvent_Descriptors","Solvent",
             "SM5.42","SM5.43","SM6","Override","Coordinates",
             "Keep");
#
# Wave functions for which SM5.42, SM5.43, and SM6 parameters exist
#
%smxopt = (
          "HF/MIDIX5D" => "1",
          "HF/MIDIX6D" => "2",
          "HF/6-31G(D)" => "3",
          "BPW91/MIDIX5D" => "4",
          "BPW91/MIDIX6D" => "5",
          "B3LYP/MIDIX5D" => "6",
          "BPW91/6-31G(D)" => "7",
          "HF/6-31+G(D)" => "8",
          "HF/CC-PVDZ" => "9",
          "BPW91/DZVP" => "10",
          "HF/6-31G(D)3" => "303",
          "B3LYP/6-31G(D)3" => "313",
          "MPW1PW91/MIDIX5D3" => "315",
          "MPW1PW91/MIDIX6D3" => "316",
          "MPW1PW91/6-31G(D)3" => "317",
          "MPW1PW91/6-31+G(D)3" => "318",
          "MPW1PW91/6-31+G(D,P)3" => "319",
          "BLYP/MIDIX6D4" => "416",
          "B3LYP/MIDIX6D4" => "416",
          "BPW91/MIDIX6D4" => "416",
          "B3PW91/MIDIX6D4" => "416",
          "MPW1PW91/MIDIX6D4" => "416",
          "BLYP/6-31G(D)4" => "417", 
          "B3LYP/6-31G(D)4" => "417",
          "BPW91/6-31G(D)4" => "417",
          "B3PW91/6-31G(D)4" => "417",
          "MPW1PW91/6-31G(D)4" => "417",
          "BLYP/6-31+G(D)4" => "418", 
          "B3LYP/6-31+G(D)4" => "418",
          "BPW91/6-31+G(D)4" => "418",
          "B3PW91/6-31+G(D)4" => "418", 
          "MPW1PW91/6-31+G(D)4" => "418",
          "BLYP/6-31+G(D,P)4" => "419",
          "B3LYP/6-31+G(D,P)4" => "419",
          "BPW91/6-31+G(D,P)4" => "419",
          "B3PW91/6-31+G(D,P)4" => "419",
          "MPW1PW91/6-31+G(D,P)4" => "419"
         );
#
# These are values of ICMD that correspond to basis sets not stored internally
# in HONDO/HONDOPLUS
#
%basfil = ("8"=>"6-31PGS.bas","14"=>"6-31PGS.bas","19"=>"6-31PGS.bas",
           "300"=>"6-31PGS.bas","10"=>"dzvp.bas","9"=>"ccpVDZ.bas",
           "314"=>"6-31PGS.bas","318"=>"6-31PGS.bas","319"=>"6-31PGSS.bas",
                                "418"=>"6-31PGS.bas","419"=>"6-31PGSS.bas");
#
# Allowed atomic numbers
#
%atom_name = ( 
                "1" => "H",
                "2" => "He",
                "3" => "Li",
                "4" => "Be",
                "5" => "B",
                "6" => "C",
                "7" => "N",
                "8" => "O",
                "9" => "F",
                "10" => "Ne",
                "11" => "Na",
                "12" => "Mg",
                "13" => "Al",
                "14" => "Si",
                "15" => "P",
                "16" => "S",
                "17" => "Cl",
                "18" => "Ar",
                "19" => "K",
                "20" => "Ca",
                "21" => "Sc",
                "22" => "Ti",
                "23" => "V",
                "24" => "Cr",
                "25" => "Mn",
                "26" => "Fe",
                "27" => "Co",
                "28" => "Ni",
                "29" => "Cu",
                "30" => "Zn",
                "31" => "Ga",
                "32" => "Ge",
                "33" => "As",
                "34" => "Se",
                "35" => "Br",
                "36" => "Kr",
                "37" => "Rb",
                "38" => "Sr",
                "39" => "Y",
                "40" => "Zr",
                "41" => "Nb",
                "42" => "Mo",
                "43" => "Tc",
                "44" => "Ru",
                "45" => "Rh",
                "46" => "Pd",
                "47" => "Ag",
                "48" => "Cd",
                "49" => "In",
                "50" => "Sn",
                "51" => "Sb",
                "52" => "Te",
                "53" => "I",
                "54" => "Xe",
                "55" => "Cs",
                "56" => "Ba",
                "57" => "La",
                "58" => "Ce",
                "59" => "Pr",
                "60" => "Nd",
                "61" => "Pm",
                "62" => "Sm",
                "63" => "Eu",
                "64" => "Gd",
                "65" => "Tb",
                "66" => "Dy",
                "67" => "Ho",
                "68" => "Er",
                "69" => "Tm",
                "70" => "Yb",
                "71" => "Lu",
                "72" => "Hf",
                "73" => "Ta",
                "74" => "W",
                "75" => "Re",
                "76" => "Os",
                "77" => "Ir",
                "78" => "Pt",
                "79" => "Au",
                "80" => "Hg",
                "81" => "Tl",
                "82" => "Pb",
                "83" => "Bi",
                "84" => "Po",
                "85" => "At",
                "86" => "Rn",
                "87" => "Fr",
                "88" => "Ra",
                "89" => "Ac",
                "90" => "Th",
                "91" => "Pa",
                "92" => "U",
                "93" => "Np",
                "94" => "Pu",
                "95" => "Am",
                "96" => "Cm",
                "97" => "Bk",
                "98" => "Cf",
                "99" => "Es",
                "100" => "Fm",
                "101" => "Md",
                "102" => "No",
                "103" => "Lr",
                "104" => "Rf",
                "105" => "Db",
                "106" => "Sg",
                "107" => "Bh",
                "108" => "Hs",
                "109" => "Mt",
                "110" => "X",
                "111" => "X",
                "112" => "X",
                "113" => "X",
                "114" => "X",
                "115" => "X",
                "116" => "X",
                "117" => "X",
                "118" => "X",
                "119" => "X",
                "120" => "X"
             ); 

#
# Figure out if user has G03 or not
# If G03 then use Gaussian external utility to carry out calculation
# 

&mode;

if ($mode2) {
$g03exe = "GAUSSIAN03";
}


# 
# Check for correct usage
#
if ($#ARGV != 1) {
   print "SMxGAuss usage: smxg2.pl input output\n";
   exit;
}  else {
   require "LIB/errmsg.lib";
}
$smxgaussinp = $ARGV[0];
$header = "######### Error #########";
$fin    = "###### Terminating ######";
$summary = $ARGV[1];
open(SMX,">$summary");
#
# Set HONDOPLUS/G03 I/O files, open punch file
#
&setio;
#
# Set up scratch directory
#
&scratchfiles;
#
# Set default run options for HONDOPLUS
#
&initialize;
#
# Print program name, authors, date, and time
#
&heading;
#
# Parse input file, collect keywords, check for errors
#
&procinput;
#
# Obtain solvation model, electronic structure method, and basis set
# Check to make sure they are consistent
#
&procsmx;
#
# Obtain solvent
#
&procsolvent;
#
# Geometry optimization options
#
&procopt;
#
# SCF options
#
&procscf;
#
# Override options
#
&procoverride;

if (not $doopt and not $dofreq) {$dosp = 1;}
#
# Check for logic errors
#
&proclogic;
#
# Summarize specified options 
#
&suminp;
#
# Read punch file specified with the Coordinates keyword
# For mode2, the Coordinates option is not required.
# For mode1, it is required
&readpunch;
#
# HONDOPLUS template file
#
&prtext;
#
# Read punch file specified by the Coordinates keyword
#
#if ($mode2 and $rpunch) { &procpunch1;&sumpunch1;}
#if ($mode1) { &procpunch2;&sumpunch2;}
if ($mode1 or ($mode2 and $rpunch)) {
   if ($dosp) {&readpunchsp2;&chargepun;}
   if ($dofreq) {&readpunchfreq2;&chargepun;}
   if ($doopt) {&readpunchopt2;&chargepun}
}
if ($mode2 and not $rpunch) {
   $punchgasstring1 = "orientation";
   $punchgasstring2 = "Rotational constants";
}

print PUN "Calculation:$lev/$bas\n";

if ($mode1) {
@rout = "";@rout = reverse @pun;
for $i (0 .. $#rout) {
   if ($rout[$i]  =~ m/Charge = \-?\d\s\s\Multiplicity = \d+/) {
      chomp($rout[$i]);
      ($c,$c,$chg,$c,$c,$mult) = split/\s+/,$rout[$i];
   }
}
   &procbasis;
   if ($dosp) {
      $typ = 1;
      $runflg = 0;
      print SMX "... Carrying out a single-point calculation in ";
      print SMX "the liquid phase ...\n\n";
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$fileout[$typ]\n\n";
      &mkhndplus;
      &runhndplus;
      &prochndout;
      &procgascharge;
      &procliqcharge;
      $ostatus = 2;
      &writeout;
      &punchgas2;
   }
   if ($doopt) {
      if (not $gasnrg) {
         if ($fccardsgas) {
            $typ = 6;
            $runflg = 2;
            print SMX "... Carrying out Gas-phase Hessian calculation ";
            print SMX "on current gas-phase\n ";
            print SMX "   Cartesian coordinates ...\n\n";
            print SMX "You can monitor this calculation by viewing the output ";
            print SMX "file for it, ";
            print SMX "which is:\n\n";
            print SMX "$scratch/$fileout[$typ]\n\n";
            &mkhndplus;
            &runhndplus;
            &prochndhess;
         }

         $typ = 0;
         $runflg  = 1;
         if ($dots) {$runflg=3;}
         print SMX "... Carrying out geometry optimization in the ";
         print SMX "gas phase ...\n\n";
         print SMX "You can monitor this calculation by viewing the output ";
         print SMX "file for it, ";
         print SMX "which is:\n\n";
         print SMX "$scratch/$fileout[$typ]\n\n";
         &mkhndplus;
         &runhndplus;
         &prochndgas; 
         &procgascharge;
         &punchgas2;
         print SMX "The gas-phase geometry optimization has completed ";
         print SMX "successfully.\n\n";
         print SMX "--- Gas-phase optimized coordinates ---\n\n";
         &printcoord;
      }
      if ($fccardssol) {
         $typ = 3;
         $runflg = 2; 
         print SMX "... Carrying out Hessian calculation in the liquid ";
         print SMX "phase to \n";
         print SMX "    facilitate liquid-phase geometry optimization ...\n\n";
         print SMX "You can monitor this calculation by viewing the output ";
         print SMX "file for it, ";
         print SMX "which is:\n\n";
         print SMX "$scratch/$fileout[$typ]\n\n";
         &mkhndplus;
         &runhndplus;
         &prochndhess;
      }
      $typ = 2;
      $runflg=1;
      if ($dots) {$runflg=3;}
      print SMX "... Carrying out geometry optimization in the ";
      print SMX "liquid phase ...\n\n";
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$fileout[$typ]\n\n";
      &mkhndplus;
      &runhndplus;
      &prochndliq;
      &procliqcharge;
      print SMX "The liquid-phase geometry optimization has completed ";
      print SMX "successfully.\n\n";
      print SMX "--- Liquid-phase optimized coordinates ---\n\n";
      &printcoord;
      &prochndout;
      print SMX "The SMxGauss summary file $hndpun2 has been saved to:\n";
      print SMX "$path\n";
      $ostatus = 2;
      &writeout;
   }
   if ($dofreq) {
      $typ = 1;
      $runflg = 0;
      print SMX "... Carrying out a single-point calculation in ";
      print SMX "the liquid phase ...\n\n";
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$fileout[$typ]\n\n";
      &mkhndplus;
      &runhndplus;
      if (not $gasnrg) {&procgascharge;}
      &prochndout;
      &procliqcharge;
      &punchgas2;
      $typ = 3;
      $runflg = 2;
      print SMX "... Carrying out Hessian calculation in the liquid ";
      print SMX "phase ...\n\n"; 
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$fileout[$typ]\n\n";
      &mkhndplus;
      &runhndplus;
      &prochndfreq;
      &prochndhess;
      print SMX "The Hessian will be printed to $hndpun2.\n\n";
      &punchhndhess;
      $ostatus=2;
      &writeout;
   }
#
# Need DoTs code here
#
#  $ostatus = 2;
#  &writeout;
#  exit;
}

if ($mode2) {   
   $typ = 5;
   &mkl202;
   &rungauss;
   &procl202;
   &procbasis;
   if ($dosp) {
      if ($gasnrg) {
         $typ = 2;
      }  else {
         $typ = 1;
      }
      $runflg = 0;
      print SMX "... Carrying out a single-point calculation in ";
      print SMX "the liquid phase ...\n\n";
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$hndout\n\n";
      &mkgauss;
      open(INF,">$scratch/.gau");
      print INF "GAU\t$typ\n";
      if ($gasnrg) {print INF "GAU\t$gasnrg\n";}
      print INF "GAU\t$iscrf\n";
      close(INF);
      close(SMX);
      &rungauss;
      open(SMX, ">>$summary");
      if (not $gasnrg) {&procgascharge;}
      &prochndout;
      &procliqcharge;
      $ostatus = 2;
      &writeout;
      &punchgas2;
   }   
   if ($doopt) {
      if (not $gasnrg) {
         if ($fccardsgas) {
            print SMX "... Carrying out Gas-phase Hessian calculation ";
            print SMX "on current gas-phase\n ";
            print SMX "   Cartesian coordinates ...\n\n";
            $typ = 6;
            $runflg = 2;
            print SMX "You can monitor this calculation by viewing the output ";
            print SMX "file for it, ";
            print SMX "which is:\n\n";
            print SMX "$scratch/$fileout[$typ]\n\n";
            &mkhndplus;
            &runhndplus;
            &procgausshess;
         }
         $typ = 0;
         $runflg  = 1;
         print SMX "... Carrying out geometry optimization in the ";
         print SMX "gas phase ...\n\n";
         &mkgauss;
         open(INF, ">$scratch/.job");print INF "FILE\t$path\/$summary\n";
         close(INF);
         open(INF, ">$scratch/.job2");print INF "STEP\t0\n";
         close(INF);
         open(INF,">$scratch/.gau");
         print INF "GAU\t$typ\n";
         print INF "GAU\t$iscrf\n";
         close(INF);
         close(SMX);
         &rungauss;
         open(SMX, ">>$summary");
         &procgaussgas; 
         &procgascharge;
         &punchgas2;
         print SMX "\n";
         print SMX "The gas-phase geometry optimization has completed ";
         print SMX "successfully.\n\n";
         print SMX "--- Gas-phase optimized coordinates ---\n\n";
         &printcoord;
      }
      if ($fccardssol) {
         $typ = 3;
         $runflg = 2;
         print SMX "... Carrying out Hessian calculation in the liquid ";
         print SMX "phase to \n";
         print SMX "    facilitate liquid-phase geometry optimization ...\n\n";
         print SMX "You can monitor this calculation by viewing the output ";
         print SMX "file for it, ";
         print SMX "which is:\n\n";
         print SMX "$scratch/$fileout[$typ]\n\n";
         &mkhndplus;
         &runhndplus;
         &procgausshess;
      }
      $typ = 2;
      $runflg=1;
      print SMX "... Carrying out geometry optimization in the ";
      print SMX "liquid phase ...\n\n";
      &mkgauss;
      open(INF, ">$scratch/.job");print INF "FILE\t$path\/$summary\n";
      close(INF);
      open(INF, ">$scratch/.job2");print INF "STEP\t0\n";
      close(INF);
      open(INF,">$scratch/.gau");
      print INF "GAU\t$typ\n";
      print INF "GAU\t$gasnrg\n";
      print INF "GAU\t$iscrf\n";
      close(INF);
      close(SMX);
      &rungauss;
      open(SMX, ">>$summary");
      &procgaussliq;
      print SMX "The liquid-phase geometry optimization has completed ";
      print SMX "successfully.\n\n";
      print SMX "--- Liquid-phase optimized coordinates ---\n\n";
      &printcoord;
      &procgaussout;
      &procliqcharge;
      print SMX "The SMxGauss summary file $hndpun2 has been saved in ";
      print SMX "the directory:\n";
      print SMX "$path\n";
      $ostatus = 2;
      &writeout;
   }
   if ($dofreq) {
#     if ($gasnrg) {
#        $typ = 2;
#     }  else {
#        $typ = 1;
#     }
      $typ = 1;
      $runflg = 0;
      print SMX "... Carrying out a single-point calculation in ";
      print SMX "the liquid phase ...\n\n";
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$hndout\n\n";
      &mkgauss;
      open(INF,">$scratch/.gau");
      if ($gasnrg) {print INF "GAU\t2\n";}else {print INF "GAU\t1\n";}
      if ($gasnrg) {print INF "GAU\t$gasnrg\n";}
      print INF "GAU\t$iscrf\n";
      close(INF);
      close(SMX);
      &rungauss;
      open(SMX, ">>$summary");
      if (not $gasnrg) {&procgascharge;}
      &procgaussout;
      &punchgas2;
      &procliqcharge;
      $typ = 3;
      $runflg = 2;
      print SMX "... Carrying out Hessian calculation in the liquid ";
      print SMX "phase ...\n\n"; 
      print SMX "You can monitor this calculation by viewing the output ";
      print SMX "file for it, ";
      print SMX "which is:\n\n";
      print SMX "$scratch/$fileout[$typ]\n\n";
      &mkhndplus;
      &runhndplus;
      &prochndfreq;
      &procgausshess;
      print SMX "The Hessian will be printed to $hndpun2.\n\n";
      &punchhndhess;
      $ostatus=2;
      &writeout;
   }
}

&clean;
